@@ -192,7 +192,7 @@ def viperconsumefromtopic(vipertoken,host,port,topic,consumerid,companyname,part
     return val
 
 def viperhpdepredict(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,inputdata,algokey='',partition=-1,offset=-1,
-                     enabletls=0,delay=0,hpdeport=-999,brokerhost='',brokerport=9092,
+                     enabletls=1,delay=1000,hpdeport=-999,brokerhost='',brokerport=9092,
                      timeout=120,usedeploy=0,microserviceid=''):
 
     #reads the fieldnames and gets latest data from each stream (or fieldname)
@@ -208,7 +208,7 @@ def viperhpdepredict(vipertoken,host,port,consumefrom,produceto,companyname,cons
     return val
 
 def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,partition=-1,offset=-1,
-                      enabletls=0,delay=100,hpdeport=-999,usedeploy=0,
+                      enabletls=1,delay=1000,hpdeport=-999,usedeploy=0,
                       ismin=1,constraints='best',stretchbounds=20,constrainttype=1,epsilon=10,brokerhost='',brokerport=9092,
                       timeout=120,microserviceid=''):
 
@@ -227,7 +227,7 @@ def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,con
     return val
 
 def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,viperconfigfile,
-                      partition=-1,modelruns=50,hpdeport=-999,offset=-1,islogistic=0,
+                      enabletls=1,partition=-1,modelruns=50,hpdeport=-999,offset=-1,islogistic=0,
                       brokerhost='',brokerport=9092,timeout=120,microserviceid=''):
 
     #reads the fieldnames and gets latest data from each stream (or fieldname)
@@ -239,7 +239,7 @@ def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,con
     value=("viperhpdetraining?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
            "&producerid="+producerid + "&companyname="+companyname + "&partition="+str(partition)+"&modelruns="+str(modelruns) +"&hpdehost=" +hpdehost +
            "&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost+ "&offset="+str(offset) + "&viperconfigfile="+viperconfigfile +
-           "&brokerport="+str(brokerport))
+           "&brokerport="+str(brokerport)+"&enabletls="+str(enabletls))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
